<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Gutener Consultancy
 */

if( !function_exists( 'gutener_layout_body_class' ) ){
	/**
	* Add a class in body
	*
	* @since Gutener Consultancy 1.0.4
	* @param array $class
	* @return array $class
	*/
	function gutener_layout_body_class( $class ){
		
		// Site Layouts
		if( get_theme_mod( 'site_layout', 'box' ) == 'default' ){
			$class[] = 'site-layout-default';
		}else if( get_theme_mod( 'site_layout', 'box' ) == 'box' ){
			$class[] = 'site-layout-box';
		}else if( get_theme_mod( 'site_layout', 'box' ) == 'frame' ){
			$class[] = 'site-layout-frame';
		}else if( get_theme_mod( 'site_layout', 'box' ) == 'full' ){
			$class[] = 'site-layout-full';
		}else if( get_theme_mod( 'site_layout', 'box' ) == 'compact' ){
			$class[] = 'site-layout-compact';
		}else if( get_theme_mod( 'site_layout', 'box' ) == 'standard' ){
			$class[] = 'site-layout-standard';
		}

		return $class;
	}
	add_filter( 'body_class', 'gutener_layout_body_class' );
}

/**
 * Filter body classes 
 *
 * @since Gutener Consultancy 1.0.4
 * @param array $class
 * @return array $class
 *
 */
function gutener_consultancy_body_class( $class ){
	// Filter the body classes
	if( get_theme_mod( 'site_layout', 'box' ) != 'default' ){
    	$class = array_diff( $class, array( 'site-layout-default' ) );
    }
    if( get_theme_mod( 'site_layout', 'box' ) != 'standard' ){
    	$class = array_diff( $class, array( 'site-layout-standard' ) );
    }

    return $class;
}
add_filter( 'body_class', 'gutener_consultancy_body_class', 99 );

if ( ! function_exists( 'navxt_gutener_breadcrumb' ) ) :
	/**
	 * Adds NavXt Breadcrumb 
	 *
	 * @since Gutener Consultancy 1.0.4
	 * @param bool $transparent_nav True for Transparent Header. 
	 *
	 */
	
	function navxt_gutener_breadcrumb( $transparent_nav = false ) { ?>
		<div class="breadcrumb-wrap">
			<?php if( $transparent_nav ){ ?>
				<div class="container">
					<div class="breadcrumbs" typeof="BreadcrumbList" vocab="https://schema.org/">
						<?php bcn_display(); ?>
					</div>
				</div>
			<?php } else{ ?>
		        <div class="breadcrumbs" typeof="BreadcrumbList" vocab="https://schema.org/">
					<?php bcn_display(); ?>
				</div>
			<?php } ?>
		</div>
	<?php }
endif;

if( !function_exists( 'gutener_has_social' ) ){
	/**
	* Check if social media icon is empty.
	* 
	* @since Gutener Consultancy 1.0.4
	* @return bool
	*/
	function gutener_has_social(){
		$social_defaults = array(
			array(
				'icon' 		=> '',
				'link' 		=> '',
				'new_tab' 	=> true,
			)			
		);
		$social_icons = get_theme_mod( 'social_media_links', $social_defaults );
		$has_social = false;
		if ( is_array( $social_icons ) ){
			foreach( $social_icons as $value ){
				if( !empty( $value['icon'] ) ){
					$has_social = true;
					break;
				}
			}
		}
		return $has_social;
	}
}

if( !function_exists( 'gutener_social' ) ){
	/**
	* Add social icons.
	* 
	* @since Gutener Consultancy 1.0.4
	*/
	function gutener_social(){
		
	    echo '<ul class="social-group">';
		    $count = 0.2;
		    $social_defaults = array(
				array(
					'icon' 		=> '',
					'link' 		=> '',
					'new_tab' 	=> true,
				)			
			);
			$social_icons = get_theme_mod( 'social_media_links', $social_defaults );
		    foreach( $social_icons as $value ){
		        if( isset( $value['new_tab'] ) && $value['new_tab'] ){
		    		$link_target = '_blank';
		    	}else{
		    		$link_target = '';
		    	}
		        if( !empty( $value['icon'] ) ){
		            echo '<li><a href="' . esc_url( $value['link'] ) . '" target="' .esc_html( $link_target ). '"><i class=" ' . esc_attr( $value['icon'] ) . '"></i></a></li>';
		            $count = $count + 0.2;
		        }
		    }
	    echo '</ul>';
	}
}